@@ -7,14 +7,13 @@ use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.004';
+$VERSION = '3.005';
 
 use base 'Mail::Reporter';
 
 use Mail::Message::Part ();
 use Mail::Message::Head::Complete ();
 use Mail::Message::Construct ();
-use Mail::Transport::Send ();
 
 use Mail::Message::Body::Lines ();
 use Mail::Message::Body::Multipart ();
@@ -162,6 +161,9 @@ my $default_mailer;
 sub send(@)
 {   my $self = shift;
 
+	# Loosely coupled module
+    require Mail::Transport::Send;
+
     my $mailer;
     $default_mailer = $mailer = shift
         if ref $_[0] && $_[0]->isa('Mail::Transport::Send');
